==> qtjambi-qml-debuginfo-macos-6.5.8.jar: sources/QtJambiQml/QQmlExtensionInterface_shell.cpp <==
#include "QQmlExtensionInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlExtensionInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlExtensionInterface")
    QQmlExtensionInterface *_ptr = reinterpret_cast<QQmlExtensionInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlExtensionInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlExtensionInterface_shell) ); }

jmethodID QQmlExtensionInterface_oshell::__shell_javaMethod(int pos) const { return QQmlExtensionInterface_shell::__shell()->javaMethod(typeid(QQmlExtensionInterface), pos); }

// emitting (writeShellDestructor)
QQmlExtensionInterface_shell::~QQmlExtensionInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlExtensionInterface::~QQmlExtensionInterface()", this)
    QQmlExtensionInterface_shell::__shell()->destructed(typeid(QQmlExtensionInterface));
}

// emitting (writeShellConstructor)
QQmlExtensionInterface_shell::QQmlExtensionInterface_shell()
    : QQmlExtensionInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlExtensionInterface::QQmlExtensionInterface_shell()", this)
    QQmlExtensionInterface_shell::__shell()->constructed(typeid(QQmlExtensionInterface));
}

void QQmlExtensionInterface_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlExtensionInterface_oshell*>(ptr)->QQmlExtensionInterface_oshell::__shell()->tryDeleteShell(typeid(QQmlExtensionInterface));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlExtensionInterface_oshell::initializeEngine(QQmlEngine* engine0, const char* uri1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        if (JniEnvironmentExceptionHandler __jni_env{400}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlExtensionInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_engine0 = qtjambi_cast<jobject>(__jni_env, engine0);
                    jstring __java_uri1 = qtjambi_cast<jstring>(__jni_env, uri1);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_engine0, __java_uri1);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlExtensionInterface_shell::__shell()->warnForMethod("QQmlExtensionInterface::initializeEngine(QQmlEngine*,const char*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QQmlExtensionInterface::initializeEngine(QQmlEngine*,const char*)");
            } QTJAMBI_TRY_END
        }
    }
}

void QQmlExtensionInterface_oshell::registerTypes(const char* uri0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        if (JniEnvironmentExceptionHandler __jni_env{300}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlExtensionInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jstring __java_uri0 = qtjambi_cast<jstring>(__jni_env, uri0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_uri0);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QQmlExtensionInterface_shell::__shell()->warnForMethod("QQmlExtensionInterface::registerTypes(const char*)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QQmlExtensionInterface::registerTypes(const char*)");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlExtensionInterface_access::__qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID engine0, jstring uri1)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QQmlEngine* __qt_engine0 = QtJambiAPI::objectFromNativeId<QQmlEngine>(engine0);
    const char* __qt_uri1 = qtjambi_cast<const char*>(__jni_env, __qtjambi_scope, uri1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlExtensionInterface::initializeEngine(QQmlEngine * engine, const char * uri)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlExtensionInterface::initializeEngine(QQmlEngine * engine, const char * uri).";
    } else {
        initializeEngine(__qt_engine0, __qt_uri1);
    }
}

void QQmlExtensionInterface_access::__qt_registerTypes_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring uri0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const char* __qt_uri0 = qtjambi_cast<const char*>(__jni_env, __qtjambi_scope, uri0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlExtensionInterface::registerTypes(const char * uri)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlExtensionInterface::registerTypes(const char * uri).";
    } else {
        registerTypes(__qt_uri0);
    }
}

// emitting (writeConstructors)
// new QQmlExtensionInterface()
void __qt_construct_QQmlExtensionInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QQmlExtensionInterface()")
    Q_UNUSED(__java_arguments)
    QQmlExtensionInterface *__qt_this = new(__qtjambi_ptr) QQmlExtensionInterface_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QQmlExtensionInterface::QQmlExtensionInterface()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlExtensionInterface_00024Impl_initialize_1native__Lio_qt_qml_QQmlExtensionInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlExtensionInterface::QQmlExtensionInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlExtensionInterface, sizeof(QQmlExtensionInterface_shell), typeid(QQmlExtensionInterface), 0, true, &deleter_QQmlExtensionInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QQmlExtensionInterface_shell
void __qt_destruct_QQmlExtensionInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlExtensionInterface")
    reinterpret_cast<QQmlExtensionInterface_shell*>(ptr)->~QQmlExtensionInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlExtensionInterface::initializeEngine(QQmlEngine*,const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlExtensionInterface_00024Impl_00024ConcreteWrapper_initializeEngine_1native_1QQmlEngine_1ptr_1const_1char_1ptr__JJLjava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID engine0,
 jstring uri1)
{
    QTJAMBI_TRY {
        QQmlExtensionInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlExtensionInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlExtensionInterface::initializeEngine(QQmlEngine*,const char*)", __this_nativeId)
        static_cast<QQmlExtensionInterface_access*>(__qt_this)->__qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(__jni_env, __this_nativeId, engine0, uri1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlExtensionInterface::registerTypes(const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlExtensionInterface_00024Impl_00024ConcreteWrapper_registerTypes_1native_1const_1char_1ptr__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jstring uri0)
{
    QTJAMBI_TRY {
        QQmlExtensionInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlExtensionInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlExtensionInterface::registerTypes(const char*)", __this_nativeId)
        static_cast<QQmlExtensionInterface_access*>(__qt_this)->__qt_registerTypes_const_char_ptr(__jni_env, __this_nativeId, uri0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlExtensionInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlExtensionInterface>("QQmlExtensionInterface", "io/qt/qml/QQmlExtensionInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "initializeEngine", "(Lio/qt/qml/QQmlEngine;Ljava/lang/String;)V", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "registerTypes", "(Ljava/lang/String;)V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QQmlExtensionInterface, {
        ConstructorInfo(&__qt_construct_QQmlExtensionInterface, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlExtensionInterface);
    registerSizeOfShell(typeId, sizeof(QQmlExtensionInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlExtensionInterface* _object = dynamic_cast<QQmlExtensionInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlExtensionInterface *object = reinterpret_cast<QQmlExtensionInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlExtensionInterface *object = reinterpret_cast<const QQmlExtensionInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
    registerPolymorphyHandler(typeid(QQmlTypesExtensionInterface), typeId, [](void *ptr, qintptr& offset) -> bool {
            QQmlTypesExtensionInterface *object = reinterpret_cast<QQmlTypesExtensionInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlExtensionInterface* _object = dynamic_cast<QQmlExtensionInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(QQmlTypesExtensionInterface), int(reinterpret_cast<quintptr>(static_cast<QQmlTypesExtensionInterface *>(reinterpret_cast<QQmlExtensionInterface *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.6.0.jar: sources/QtJambiQml/QQmlExtensionInterface_shell.cpp <==
#include "QQmlExtensionInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QQmlExtensionInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlExtensionInterface")
    QQmlExtensionInterface *_ptr = reinterpret_cast<QQmlExtensionInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QQmlExtensionInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QQmlExtensionInterface_shell) ); }

jmethodID QQmlExtensionInterface_shell::__shell_javaMethod(int pos) const { return QQmlExtensionInterface_shell::__shell()->javaMethod(typeid(QQmlExtensionInterface), pos); }

// emitting (writeShellConstructor)
QQmlExtensionInterface_shell::QQmlExtensionInterface_shell()
    : QQmlExtensionInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QQmlExtensionInterface::QQmlExtensionInterface_shell()", QQmlExtensionInterface_shell::__shell())
    QQmlExtensionInterface_shell::__shell()->constructed(typeid(QQmlExtensionInterface));
}

// emitting (writeShellDestructor)
QQmlExtensionInterface_shell::~QQmlExtensionInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QQmlExtensionInterface::~QQmlExtensionInterface()", QQmlExtensionInterface_shell::__shell())
    QQmlExtensionInterface_shell::__shell()->destructed(typeid(QQmlExtensionInterface));
}

void QQmlExtensionInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QQmlExtensionInterface_shell*>(ptr)->QQmlExtensionInterface_shell::__shell()->tryDeleteShell(typeid(QQmlExtensionInterface));
}

// emitting Virtual overrides (virtualFunctions)
void QQmlExtensionInterface_shell::initializeEngine(QQmlEngine* engine0, const char* uri1)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlExtensionInterface::", QQmlExtensionInterface_shell::__shell())
        if(JniEnvironment __jni_env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlExtensionInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_engine0 = qtjambi_cast<jobject>(__jni_env, engine0);
                    jstring __java_uri1 = qtjambi_cast<jstring>(__jni_env, uri1);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_engine0, __java_uri1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QQmlExtensionInterface_shell::__shell()->warnForMethod("QQmlExtensionInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QQmlExtensionInterface::");
            } QTJAMBI_TRY_END
        }
    }
}

void QQmlExtensionInterface_shell::registerTypes(const char* uri0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QQmlExtensionInterface::", QQmlExtensionInterface_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QQmlExtensionInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jstring __java_uri0 = qtjambi_cast<jstring>(__jni_env, uri0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_uri0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QQmlExtensionInterface_shell::__shell()->warnForMethod("QQmlExtensionInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QQmlExtensionInterface::");
            } QTJAMBI_TRY_END
        }
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
void QQmlExtensionInterface_access::__qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID engine0, jstring uri1)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QQmlEngine* __qt_engine0 = QtJambiAPI::objectFromNativeId<QQmlEngine>(engine0);
    const char*  __qt_uri1 = qtjambi_cast<const char* >(__jni_env, __qtjambi_scope, uri1);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlExtensionInterface::initializeEngine(QQmlEngine * engine, const char * uri)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlExtensionInterface::initializeEngine(QQmlEngine * engine, const char * uri).";
    } else {
        initializeEngine(__qt_engine0, __qt_uri1);
    }
}

void QQmlExtensionInterface_access::__qt_registerTypes_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring uri0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const char*  __qt_uri0 = qtjambi_cast<const char* >(__jni_env, __qtjambi_scope, uri0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QQmlExtensionInterface::registerTypes(const char * uri)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QQmlExtensionInterface::registerTypes(const char * uri).";
    } else {
        registerTypes(__qt_uri0);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QQmlExtensionInterface_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QQmlExtensionInterface *__qt_this = new(__qtjambi_ptr) QQmlExtensionInterface_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QQmlExtensionInterface_shell
void __qt_destruct_QQmlExtensionInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlExtensionInterface")
    reinterpret_cast<QQmlExtensionInterface_shell*>(ptr)->~QQmlExtensionInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlExtensionInterface::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlExtensionInterface_00024Impl_initialize_1native__Lio_qt_qml_QQmlExtensionInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlExtensionInterface::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QQmlExtensionInterface_0, sizeof(QQmlExtensionInterface_shell), typeid(QQmlExtensionInterface), true, &deleter_QQmlExtensionInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlExtensionInterface::initializeEngine(QQmlEngine*,const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlExtensionInterface_00024Impl_00024ConcreteWrapper_initializeEngine_1native_1QQmlEngine_1ptr_1const_1char_1ptr__JJLjava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID engine0,
 jstring uri1)
{
    QTJAMBI_TRY {
        QQmlExtensionInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlExtensionInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlExtensionInterface::initializeEngine(QQmlEngine*,const char*)", __qt_this)
        static_cast<QQmlExtensionInterface_access*>(__qt_this)->__qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(__jni_env, __this_nativeId, engine0, uri1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlExtensionInterface::registerTypes(const char*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlExtensionInterface_00024Impl_00024ConcreteWrapper_registerTypes_1native_1const_1char_1ptr__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 jstring uri0)
{
    QTJAMBI_TRY {
        QQmlExtensionInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QQmlExtensionInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QQmlExtensionInterface::registerTypes(const char*)", __qt_this)
        static_cast<QQmlExtensionInterface_access*>(__qt_this)->__qt_registerTypes_const_char_ptr(__jni_env, __this_nativeId, uri0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlExtensionInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QQmlExtensionInterface>("QQmlExtensionInterface", "io/qt/qml/QQmlExtensionInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "initializeEngine", "(Lio/qt/qml/QQmlEngine;Ljava/lang/String;)V", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "registerTypes", "(Ljava/lang/String;)V", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QQmlExtensionInterface, {
        ConstructorInfo(&__qt_construct_QQmlExtensionInterface_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlExtensionInterface);
    registerSizeOfShell(typeId, sizeof(QQmlExtensionInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlExtensionInterface* _object = dynamic_cast<QQmlExtensionInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QQmlExtensionInterface *object = reinterpret_cast<QQmlExtensionInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QQmlExtensionInterface *object = reinterpret_cast<const QQmlExtensionInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
    registerPolymorphyHandler(typeid(QQmlTypesExtensionInterface), typeId, [](void *ptr, qintptr& offset) -> bool {
            QQmlTypesExtensionInterface *object = reinterpret_cast<QQmlTypesExtensionInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QQmlExtensionInterface* _object = dynamic_cast<QQmlExtensionInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(QQmlTypesExtensionInterface), int(reinterpret_cast<quintptr>(static_cast<QQmlTypesExtensionInterface *>(reinterpret_cast<QQmlExtensionInterface *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}
